@@ -1,4 +1,5 @@
-from ..data.ls_dyna import DEForc, Elout, EloutObject, Glstat, Matsum, Nodout, RCForc, SBTout, Secforc, Disbout, PartDisbout, Abstat
+
+from ..data.ls_dyna import DEForc, Elout, EloutObject, Glstat, Matsum, Nodout, RCForc, SBTout, Secforc, Disbout, PartDisbout, Abstat, AbstatCPM, JointForc
 from ..utils.constants import ObjectConstantsForData
 
 
@@ -13,6 +14,7 @@ class DataContainer:
     _rcforc = None
     _deforc = None
     _nodout = None
+    _joint_forc = None
     _volume = None
     _sbtout = None
     _matsum = None
@@ -20,6 +22,7 @@ class DataContainer:
     _disbout = None
     _part_disbout = None
     _abstat = None
+    _abstat_cpm = None
 
     @staticmethod
     def get_data(name):
@@ -38,6 +41,8 @@ class DataContainer:
             return DataContainer._deforc
         elif name == ObjectConstantsForData.NODE:
             return DataContainer._nodout
+        elif name == ObjectConstantsForData.JOINT:
+            return DataContainer._joint_forc
         elif name == ObjectConstantsForData.SEAT_BELT:
             return DataContainer._sbtout
         elif name == ObjectConstantsForData.CONTACT:
@@ -52,6 +57,8 @@ class DataContainer:
             return DataContainer._part_disbout
         elif name == ObjectConstantsForData.AIRBAG:
             return DataContainer._abstat
+        elif name == ObjectConstantsForData.AIRBAG_CPM:
+            return DataContainer._abstat_cpm
         return
 
     @staticmethod
@@ -69,6 +76,7 @@ class DataContainer:
         DataContainer._elout = Elout(binout, logger, dynasaur_def)
         DataContainer._elout_object = EloutObject(binout, logger, dynasaur_def, volume_path=volume_path)
         DataContainer._nodout = Nodout(binout, logger, dynasaur_def)
+        DataContainer._joint_forc = JointForc(binout, logger, dynasaur_def)
         DataContainer._deforc = DEForc(binout, logger, dynasaur_def)
         DataContainer._disbout = Disbout(binout, logger, dynasaur_def)
         DataContainer._part_disbout = PartDisbout(binout, logger, dynasaur_def)
@@ -77,17 +85,5 @@ class DataContainer:
         DataContainer._matsum = Matsum(binout, logger, dynasaur_def)
         DataContainer._glstat = Glstat(binout, logger, dynasaur_def)
         DataContainer._abstat = Abstat(binout, logger, dynasaur_def)
-
-    @staticmethod
-    def init_data_source_nodout(madymo, logger, dynasaur_def):
-        """
-        Init nodout data source
-
-        :param: madymo
-        :param: logger
-        :param: dynasaur definitions
-
-        :return:
-        """
-        DataContainer._nodout = Nodout(madymo, logger, dynasaur_def, code_type=CodeType.MADYMO)
+        DataContainer._abstat_cpm = AbstatCPM(binout, logger, dynasaur_def)
 
