@@ -77,6 +77,7 @@ class DynasaurDefinitions:
         # set all class members
         self._cross_sections = {}
         self._node = {}
+        self._jntforc = {}
         self._disbout = {}
         self._part_disbout = {}
         self._contact = {}
@@ -86,6 +87,7 @@ class DynasaurDefinitions:
         self._energy_part = {}
         self._energy_global = {}
         self._abstat = {}
+        self._abstat_cpm = {}
         self._riskfunction = {DefFileConstants.FUNC_CRITERIA: {},
                               DefFileConstants.FUNC_DATA_VISUALIZATION: {}}
 
@@ -157,6 +159,8 @@ class DynasaurDefinitions:
         d = {}
         if data_container == "nodout":
             d = self._node
+        elif data_container == "jntforc":
+            d = self._jntforc
         elif data_container == "rcforc":
             d = self._contact
         elif data_container == "deforc":
@@ -177,6 +181,8 @@ class DynasaurDefinitions:
             d = self._part_disbout
         elif data_container == "abstat":
             d = self._abstat
+        elif data_container == "abstat_cpm":
+            d = self._abstat_cpm
 
         if name not in d.keys() or len(d) == 0:
             self._logger.emit(LOGConstants.ERROR[0],
@@ -328,8 +334,6 @@ class DynasaurDefinitions:
         if JsonConstants.PART_ID in json_object:
             def_container[name] = json_object[JsonConstants.PART_ID]
 
-
-
     def __set_object(self, json_object):
         """
         set object
@@ -369,8 +373,12 @@ class DynasaurDefinitions:
                 self.__set_object(json_object)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.NODE:
                 self._set_datacontainer_defintion(json_object, self._node)
+            elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.JOINT:
+                self._set_datacontainer_defintion(json_object, self._jntforc)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.AIRBAG:
                 self._set_datacontainer_defintion(json_object, self._abstat)
+            elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.AIRBAG_CPM:
+                self._set_datacontainer_defintion(json_object, self._abstat_cpm)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.DISBOUT:
                 self._set_datacontainer_defintion(json_object, self._disbout)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.ELEMENT:
