@@ -480,7 +480,7 @@ class EloutObject(BinoutData):
         elif (elout_elem == "shell" and what == "strain"):
             # ok
             nr_elements = time.shape[0] if isinstance(self._binout.read(self._name, elout_elem, 'ids')[0],
-                                                      np.int32) else len(
+                                                      np.intp) else len(
                 self._binout.read(self._name, elout_elem, 'ids')[0]) * time.shape[0]
             rep_strain = np.repeat([2], nr_elements, axis=0)
             ids = np.repeat(np.tile(self._binout.read(self._name, elout_elem, 'ids')[0], time.shape[0]).flatten(),
@@ -530,7 +530,7 @@ class EloutObject(BinoutData):
         ids = self._binout.read(self._name, elout_elem, 'ids')
 
         # check if elements have been destroyed
-        if isinstance(ids[0], np.int32):
+        if isinstance(ids[0], np.intp): # or isinstance(ids[0], np.int64):
             ids = [np.array([i]) for i in ids]
         if sum([len(i) - len(ids[0]) for i in ids]) == 0:
             return insert_indices, ind
@@ -689,7 +689,7 @@ class EloutObject(BinoutData):
 
         if elout_elem == "shell":
             nr_elements = time.shape[0] if isinstance(self._binout.read(self._name, elout_elem, 'ids')[0],
-                                                      np.int32) else len(
+                                                      np.intp) else len(
                 self._binout.read(self._name, elout_elem, 'ids')[0]) * time.shape[0]
 
             ind_array = np.arange(1, nr_elements + 1)
